@@ -15,8 +15,10 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+              '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+              '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -24,62 +26,57 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O2 '
-           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+ 'CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O3 '
+           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
            '-Wformat -Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-           '-fno-semantic-interposition',
+           '-fcf-protection         -fno-omit-frame-pointer '
+           '-mno-omit-leaf-frame-pointer -ffat-lto-objects -march=x86-64 '
+           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection         '
+           '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -march=x86-64 '
+           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection         '
+           '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+ 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-fcf-protection -g '
-                     '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                     '-fno-semantic-interposition',
- 'CONFIGURE_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
-                            '-flto-partition=none -g -std=c11 '
+                     '-fcf-protection         -fno-omit-frame-pointer '
+                     '-mno-omit-leaf-frame-pointer -ffat-lto-objects',
+ 'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -std=c11 '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'CONFIGURE_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
-                             '-flto-partition=none -g',
- 'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                      '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
+ 'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
+ 'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'ax_cv_c_float_words_bigendian=no' '--prefix=/usr' "
-                "'--enable-shared' '--with-computed-gotos' '--with-lto' "
-                "'--enable-ipv6' '--with-system-expat' "
-                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
+                "'--enable-shared' '--with-computed-gotos' "
+                "'--enable-optimizations' '--with-lto=no' '--enable-ipv6' "
+                "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=x86-64 "
-                '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
-                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
-                '-fcf-protection -g '
-                '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                "-fno-semantic-interposition' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now'",
+                '-fcf-protection         -fno-omit-frame-pointer '
+                "-mno-omit-leaf-frame-pointer -ffat-lto-objects' "
+                "'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed "
+                "-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python311/src/Python-3.11.9/coverage.info',
+ 'COVERAGE_INFO': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python311/src/Python-3.11.9/lcov-report',
+ 'COVERAGE_REPORT': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -152,7 +149,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 1,
+ 'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -192,7 +189,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DB_H': 1,
+ 'HAVE_DB_H': 0,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -331,8 +328,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
- 'HAVE_LIBB2': 0,
- 'HAVE_LIBDB': 1,
+ 'HAVE_LIBB2': 1,
+ 'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBGDBM_COMPAT': 1,
@@ -631,39 +628,39 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -Wl,-O1 '
+            '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+             '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+             '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 '
-                    '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                    '-O2 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-fcf-protection         -fno-omit-frame-pointer '
+                    '-mno-omit-leaf-frame-pointer -ffat-lto-objects '
+                    '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                    '-O2 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-fcf-protection         -fno-omit-frame-pointer '
+                    '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic '
+                    '-O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                    '-Werror=implicit-function-declaration '
+                    '-fcf-protection         -fno-omit-frame-pointer '
+                    '-mno-omit-leaf-frame-pointer -fno-semantic-interposition '
+                    '-std=c11 -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
@@ -672,26 +669,22 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -DNDEBUG -g '
-                    '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O2 -pipe '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                    '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O3 -pipe '
+                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                     '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                    '-O2 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-fstack-clash-protection -fcf-protection         '
+                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                    '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe '
+                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                    '-Wformat -Werror=format-security         '
+                    '-fstack-clash-protection -fcf-protection         '
+                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                    '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                    '-O2 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                    '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                    '-Werror=implicit-function-declaration '
+                    '-fcf-protection         -fno-omit-frame-pointer '
+                    '-mno-omit-leaf-frame-pointer -fno-semantic-interposition '
+                    '-std=c11 -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -816,7 +809,7 @@ build_time_vars = {'ABIFLAGS': '',
                         './Modules/_blake2/impl/blake2s-round.h '
                         './Modules/_blake2/impl/blake2s.c '
                         './Modules/_blake2/blake2module.h ./Modules/hashlib.h',
- 'MODULE__BLAKE2_LDFLAGS': '',
+ 'MODULE__BLAKE2_LDFLAGS': '-lb2',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
@@ -923,7 +916,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_STATE': 'missing',
+ 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
+ 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
+ 'MODULE__TKINTER_STATE': 'yes',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
@@ -979,110 +974,104 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 '
-                             '-mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-mtune=generic -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                             '-fno-semantic-interposition -march=x86-64 '
-                             '-mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer -ffat-lto-objects '
+                             '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                             '-fno-semantic-interposition -march=x86-64 '
-                             '-mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer -march=x86-64 '
+                             '-mtune=generic -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                             '-fno-semantic-interposition -flto '
-                             '-fuse-linker-plugin -ffat-lto-objects '
-                             '-flto-partition=none -g -std=c11 '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer '
+                             '-fno-semantic-interposition -std=c11 '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O2 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+ 'PY_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 -mtune=generic -O3 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
               '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+              '-fstack-clash-protection -fcf-protection         '
+              '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+              '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe '
+              '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection         -fno-omit-frame-pointer '
+              '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic -O3 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
               '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-              '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-              '-fno-semantic-interposition',
- 'PY_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
-                     '-flto-partition=none -g -std=c11 '
+              '-fstack-clash-protection -fcf-protection         '
+              '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer',
+ 'PY_CFLAGS_NODIST': '-fno-semantic-interposition -std=c11 '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 -mtune=generic '
-                   '-O2 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                   '-O2 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -ffat-lto-objects '
+                   '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                   '-O2 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic '
+                   '-O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto '
-                    '-fuse-linker-plugin -ffat-lto-objects '
-                    '-flto-partition=none -g',
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -fno-semantic-interposition '
+                   '-std=c11 -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now          -Wl,-z,pack-relative-relocs -Wl,-O1 '
+                    '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                    '-fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'PY_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
-                      '-flto-partition=none -g',
- 'PY_LDFLAGS_NOLTO': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-fno-lto',
+ 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -Wl,-O1 '
+               '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
+ 'PY_LDFLAGS_NODIST': '-fno-semantic-interposition',
+ 'PY_LDFLAGS_NOLTO': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                     '-Wl,-z,now          -Wl,-z,pack-relative-relocs -Wl,-O1 '
+                     '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                     '-Wl,-z,now          -Wl,-z,pack-relative-relocs',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=x86-64 '
-                        '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-mtune=generic -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                        '-fno-semantic-interposition -march=x86-64 '
-                        '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
+                        '-pipe -fno-plt -fexceptions         '
+                        '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                        '-fno-semantic-interposition -march=x86-64 '
-                        '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python311/src=/usr/src/debug/python311 '
-                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -flto-partition=none -g -std=c11 '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-fno-semantic-interposition -std=c11 '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -1097,7 +1086,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1141,10 +1130,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13 '
+               './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9 ./python -E '
-               './Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13 '
+               './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1161,7 +1151,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -1174,8 +1164,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python311/src/Python-3.11.9',
- 'abs_srcdir': '/build/python311/src/Python-3.11.9',
+ 'abs_builddir': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
+ 'abs_srcdir': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
